@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 25-01-2021
@@ -10,7 +10,8 @@ __doc__ = r"""
 __all__ = ["Drawer"]
 
 from abc import abstractmethod
-from typing import Sequence, MutableMapping
+from typing import Sequence, MutableMapping, Any
+
 from warg import drop_unused_kws
 
 
@@ -24,7 +25,7 @@ class Drawer(object):
         self._verbose = verbose
 
     @abstractmethod
-    def draw(self, *args: Sequence, **kwargs: MutableMapping) -> None:
+    def draw(self, *args: Sequence[Any], **kwargs: MutableMapping[str, Any]) -> None:
         """description"""
         raise NotImplementedError
 
