@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = """
 Created on 27/04/2019
 
@@ -11,21 +11,22 @@ Created on 27/04/2019
 
 __all__ = ["DiscreteScrollPlot", "discrete_scroll_plot"]
 
-from typing import Iterator, Sequence, Tuple, MutableMapping
+from typing import Iterator, Sequence, Tuple, MutableMapping, Any
 
 import numpy
+from draugr.drawers.mpl_drawers.mpldrawer import MplDrawer
+from draugr.numpy_utilities import recursive_flatten_numpy
 from matplotlib import animation
 from matplotlib import pyplot
 
-from draugr.drawers.mpl_drawers.mpldrawer import MplDrawer
-from draugr.numpy_utilities import recursive_flatten_numpy
 from warg import passes_kws_to
 
 
 class DiscreteScrollPlot(MplDrawer):
     """
     Waterfall plot
-    only supports a single trajectory at a time, do not supply parallel trajectories to draw method, will get truncated to num actions, effectively dropping actions for other envs than the first."""
+    only supports a single trajectory at a time, do not supply parallel trajectories to draw method, will get truncated to num actions, effectively dropping actions for other envs than the first.
+    """
 
     @passes_kws_to(MplDrawer.__init__)
     def __init__(
@@ -43,7 +44,6 @@ class DiscreteScrollPlot(MplDrawer):
         figure_size: Tuple[int, int] = None,
         **kwargs
     ):
-
         super().__init__(render=render, figure_size=figure_size, **kwargs)
         if not render:
             return
@@ -257,7 +257,9 @@ if __name__ == "__main__":
                 def __next__(self):
                     return self.get()
 
-                def __call__(self, *args: Sequence, **kwargs: MutableMapping):
+                def __call__(
+                    self, *args: Sequence[Any], **kwargs: MutableMapping[str, Any]
+                ):
                     return self.__next__()
 
                 def add(self, a):
