@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 22/11/2019
@@ -13,9 +13,9 @@ __all__ = ["DistributionPlot"]
 from typing import Sequence
 
 import numpy
+from draugr.drawers.mpl_drawers.mpldrawer import MplDrawer
 from matplotlib import pyplot
 
-from draugr.drawers.mpl_drawers.mpldrawer import MplDrawer
 from warg import passes_kws_to
 
 
