@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
                Image stream plot using matplotlib
 
@@ -12,11 +12,13 @@ __all__ = ["ImageStreamPlot"]
 
 from typing import Sequence
 
-from matplotlib import pyplot
 import matplotlib
 from draugr.drawers.mpl_drawers.mpldrawer import MplDrawer
+from matplotlib import pyplot
+
 from warg import passes_kws_to
 
+
 # pyplot.switch_backend("QtAgg")  # MacOSX, QtAgg, GTK4Agg, Gtk3Agg, TkAgg, WxAgg, Agg
 
 
