@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 21/09/2019
@@ -14,9 +14,8 @@ from abc import abstractmethod
 from typing import Any, Sequence, Tuple, MutableMapping
 
 import matplotlib
-from matplotlib import pyplot
-
 from draugr.drawers.drawer import Drawer
+from matplotlib import pyplot
 
 
 # TODO: implement a key for closing the plot
@@ -26,6 +25,8 @@ from draugr.drawers.drawer import Drawer
 # fig.canvas.mpl_connect('key_press_event', lambda evt: print(repr(evt.key))) # print key pressed
 # plt.rcParams['keymap.quit'].append(' ')
 
+# pyplot.switch_backend("QtAgg")  # MacOSX, QtAgg, GTK4Agg, Gtk3Agg, TkAgg, WxAgg, Agg
+
 
 class MplDrawer(
     # metaclass=PostInit
