@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 22/11/2019
@@ -12,10 +12,9 @@ __doc__ = r"""
 from typing import Sequence, Union, MutableMapping
 
 import numpy
-from matplotlib import pyplot
-
 from draugr.drawers.mpl_drawers.mpldrawer import MplDrawer
 from draugr.numpy_utilities import recursive_flatten_numpy
+from matplotlib import pyplot
 
 __all__ = ["SeriesScrollPlot"]
 
