@@ -1,16 +1,16 @@
-import os
 import subprocess
 from pathlib import Path
 from typing import Optional
 
-from warg import ensure_existence
 from draugr.ffmpeg_utilities.extract import AUDIO_FORMAT
+
 from warg import Number, identity
+from warg import ensure_existence
 
 __all__ = ["merge_frames"]
 
 
-def get_frame_format(frames_dir, formats=(".jpg", ".png")) -> str:
+def get_frame_format(frames_dir: Path, formats=(".jpg", ".png")) -> str:
     """
 
     :param frames_dir:
@@ -57,6 +57,11 @@ def merge_frames(
     if merge_dir is None:
         merge_dir = ensure_existence(vid_dir / "merge", sanitisation_func=identity)
 
+    shortname = vid_dir.name
+
+    # a = f"{shortname}-%05d{postfix}{get_frame_format(frames_dir)}"  # 05d is for 5 digits in ids
+    # a = "brandt.mp4-%*_00.png"
+    a = f"%05d{get_frame_format(frames_dir)}"
     temp_out = str(merge_dir / "temp.mp4")
     subprocess.call(
         [
@@ -77,9 +82,9 @@ def merge_frames(
     )
 
     a = []
-    shortname = frames_dir.parent.name
+
     if merge_audio:
-        sound_dir = audio_dir / ("track" + AUDIO_FORMAT)
+        sound_dir = (audio_dir / "track").with_suffix(f".{AUDIO_FORMAT.lstrip('.')}")
         if sound_dir.exists():
             a.extend(["-i", str(sound_dir)])
         else:
@@ -96,20 +101,14 @@ def merge_frames(
             "-acodec",
             "copy",
             "-y",
-            str(merge_dir / f"out.mp4"),
+            str((merge_dir / "out").with_suffix(f".{'mp4'.lstrip('.')}")),
         ]
     )
 
 
 if __name__ == "__main__":
     merge_frames(
-        Path.home()
-        / "DataWin"
-        / "DeepFake"
-        / "Frontier"
-        / "Originals"
-        / "thomas_old_high_res"
-        / "frames",
+        Path.home() / "DataWin" / "frames",
         ffmpeg_path=Path.home()
         / "OneDrive - Alexandra Instituttet"
         / "Applications"
