@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 26/03/2020
@@ -16,13 +16,13 @@ with open(Path(__file__).parent / "README.md", "r") as this_init_file:
 try:
     from .channel_transform import *
     from .manipulation import *
-    from .resize import *
     from .datasets import *
     from .sampling import *
     from .powers import *
     from .signal_utilities import *
     from .raster_grid_2d_masking import *
     from .mixing import *
+    from .hashing import *
 except ImportError as ix:
     this_package_name = Path(__file__).parent.name
     this_package_reqs = (
