@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 21/07/2020
@@ -9,7 +9,7 @@ __doc__ = r"""
 
 import os
 from pathlib import Path
-from typing import Iterable, Union
+from typing import Iterable, Union, Callable
 
 __all__ = ["build_flat_dataset"]
 
@@ -20,7 +20,7 @@ def build_flat_dataset(
     validation_percentage: float = 15,
     testing_percentage: float = 0,
     extensions: Iterable = None,
-    is_valid_file: callable = None,
+    is_valid_file: Callable = None,
 ) -> dict:
     """
 
