@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 04/03/2020
@@ -13,8 +13,8 @@ from typing import Optional, Sequence, Tuple, Union
 import cv2
 import numpy
 from PIL import Image, ImageDraw, ImageFont
-
 from draugr.opencv_utilities.drawing.opencv_draw import draw_masks
+
 from warg import RGB, compute_color_for_labels
 
 __all__ = ["draw_single_box", "draw_bounding_boxes", "draw_single_rect"]
