@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 19/03/2020
@@ -12,11 +12,11 @@ from typing import Sequence, Tuple, Union
 import cv2
 import numpy
 from PIL import Image
-
 from draugr.opencv_utilities.namespaces.enums import (
     LineTypeEnum,
     ContourRetrievalModeEnum,
 )
+
 from warg import RGB, compute_color_for_labels
 
 __all__ = ["find_contours", "draw_masks"]
