@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 25-01-2021
@@ -68,7 +68,7 @@ class AsyncVideoStream:
         """Returns whether the stream is open"""
         return self._stream.isOpened()
 
-    def __call__(self, *args: Sequence, **kwargs: MutableMapping):
+    def __call__(self, *args: Sequence[Any], **kwargs: MutableMapping[str, Any]):
         return self.frame
 
     def __next__(self):
