@@ -1,15 +1,15 @@
-from typing import Optional
+from typing import Callable
 
 import cv2
+from draugr.opencv_utilities import ButtonTypeEnum
 
 from warg import sink
-from draugr.opencv_utilities import ButtonTypeEnum
 
 __all__ = ["add_button"]
 
 
 def add_button(
-    checkbox_name: str, *, callback: callable = sink, new_line: bool = True
+    checkbox_name: str, *, callback: Callable = sink, new_line: bool = True
 ) -> None:
     """
     :param checkbox_name:
