@@ -1,9 +1,9 @@
-from typing import Optional
+from typing import Callable
 
 import cv2
+from draugr.opencv_utilities import ButtonTypeEnum
 
 from warg import sink
-from draugr.opencv_utilities import ButtonTypeEnum
 
 __all__ = ["add_checkbox"]
 
@@ -12,7 +12,7 @@ def add_checkbox(
     checkbox_name: str,
     *,
     initial_button_state: bool = False,
-    callback: callable = sink,
+    callback: Callable = sink,
     new_line: bool = True
 ) -> None:
     """
