@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 03/08/2020
@@ -15,7 +15,6 @@ if INCLUDE_PROJECT_READMES:
     with open(Path(__file__).parent / "README.md", "r") as this_init_file:
         __doc__ += this_init_file.read()
 
-
 try:
     from .gtk_settings import *
     from .theme_preferences import *
