@@ -1,13 +1,12 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 17-05-2021
            """
 
-
 from pathlib import Path
 
 with open(Path(__file__).parent / "README.md", "r") as this_init_file:
