@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
             Small path_utilities to keep track of cores dedicated to workers threads
@@ -11,6 +11,7 @@ __doc__ = r"""
 
 import os
 from typing import MutableMapping
+
 from warg import AlsoDecorator, passes_kws_to
 
 CORE_COUNT: int = os.cpu_count()
