@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 26-01-2021
@@ -62,7 +62,6 @@ def duplicate_columns(frame: pandas.DataFrame) -> List[str]:
     duplicates = []
 
     for t, v in groups.items():
-
         cs = frame[v].columns
         vs = frame[v]
         lcs = len(cs)
