@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 27-05-2021
@@ -14,8 +14,8 @@ from typing import List, Union
 from pandas.core.generic import NDFrame
 from sorcery import assigned_names
 
-from warg import ensure_existence
 from warg import Number
+from warg import ensure_existence
 
 __all__ = [
     "color_highlight_extreme",
