@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 14/01/2020
@@ -11,13 +11,14 @@ __doc__ = r"""
 #    __doc__ += this_init_file.read()  # .replace("#", "")  # .encode("ascii", "ignore")
 
 
+from .counter_filter import *
+from .display import *
 from .function_wrappers import *
 from .generators import *
 from .http import *
+from .iterators import *
+from .matrix import *
+from .platform_context import *
 from .sockets import *
 from .torch_like_channel_transformation import *
-from .counter_filter import *
-from .matrix import *
-from .iterators import *
-from .display import *
-from .platform_context import *
+from .styling import *
