@@ -1,19 +1,9 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-import os
-import shutil
-from pathlib import Path
-from random import randint
-from time import time
-from typing import Any, List, Mapping, Sequence, Union
 
-import numpy
+__author__ = "Christian Heider Lindbjerg"
 
-from warg import NOD, passes_kws_to
-
-__author__ = "Christian Heider Nielsen"
-
-import six
+__doc__ = """description"""
 
 __all__ = [
     "COLORS",
@@ -21,12 +11,22 @@ __all__ = [
     "generate_style",
     "sprint",
     "PrintStyle",
-    "scale",
     "get_terminal_size",
     "hyperlink_path",
     "hyperlink_url",
 ]
 
+import os
+import shutil
+from pathlib import Path
+from random import randint
+from time import time
+from typing import Any, Union
+
+import six
+
+from warg import NOD, passes_kws_to
+
 COLORS = NOD(
     red="31",
     green="32",
@@ -61,7 +61,7 @@ DECORATIONS = NOD(
 def hyperlink_url(
     link: str, link_id: str = None, style: bool = False, prefix: str = "https://"
 ) -> str:
-    """ """
+    """description"""
     if not link.startswith(prefix):
         if "://" in link:
             link = f'{prefix}{link.split("://")[1]}'
@@ -78,7 +78,7 @@ def hyperlink_url(
 def hyperlink_path(
     link: Path, link_id: str = None, style: bool = False, linux: bool = True
 ) -> str:
-    """ """
+    """description"""
     if linux:
         link = f"file://{link.resolve()}"
     if not style:
@@ -89,7 +89,7 @@ def hyperlink_path(
 
 
 class PrintStyle(object):
-    """ """
+    """description"""
 
     def __init__(self, attributes_joined, end):
         self._attributes_joined = attributes_joined
@@ -166,32 +166,15 @@ def generate_style(
 
 
 @passes_kws_to(generate_style)
-def sprint(obj: Any, print_kws: Mapping = {}, **kwargs) -> None:
+def sprint(obj: Any, print_kws=None, **kwargs) -> None:
     """
     Stylised print. Defaults to stdout
     Valid colors: gray, red, green, yellow, blue, magenta, cyan, white, crimson"""
+    if print_kws is None:
+        print_kws = {}
     print(generate_style(obj, **kwargs), **print_kws)
 
 
-def scale(x: Sequence, length: float) -> List[int]:
-    """
-    Scale points in 'x', such that distance between
-    max(x) and min(x) equals to 'length'. min(x)
-    will be moved to 0."""
-    if type(x) is list:
-        s = float(length) / (max(x) - min(x)) if x and max(x) - min(x) != 0 else length
-    # elif type(x) is range:
-    #  s = length
-    else:
-        s = (
-            float(length) / (numpy.max(x) - numpy.min(x))
-            if len(x) and numpy.max(x) - numpy.min(x) != 0
-            else length
-        )
-
-    return [int((i - min(x)) * s) for i in x]
-
-
 def get_terminal_size() -> NOD:
     """
 
