@@ -2,18 +2,18 @@
 # -*- coding: utf-8 -*-
 
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = ""
 
 __all__ = ["add_early_stopping_key_combination", "CaptureEarlyStop"]
 
 import contextlib
 from time import sleep
-from typing import Callable, Iterable, Sequence, MutableMapping
+from typing import Callable, Iterable, Sequence, MutableMapping, Any
 
 from pynput.keyboard import KeyCode
-
-from warg import GDKC, drop_unused_kws, passes_kws_to, sprint
+from draugr.python_utilities.styling import sprint
+from warg import GDKC, drop_unused_kws, passes_kws_to
 
 # import keyboard
 
@@ -45,7 +45,6 @@ def add_early_stopping_key_combination(
     verbose: bool = False,
     combinations: Iterable = default_combinations,
 ):  # -> keyboard.Listener:
-
     """
 
     :param combinations:
@@ -105,7 +104,7 @@ class CaptureEarlyStop(contextlib.AbstractContextManager):
     Context for early stopping a loop"""
 
     @passes_kws_to(add_early_stopping_key_combination)
-    def __init__(self, *args: Sequence, **kwargs: MutableMapping):
+    def __init__(self, *args: Sequence[Any], **kwargs: MutableMapping[str, Any]):
         self.listener = add_early_stopping_key_combination(*args, **kwargs)
 
     def __enter__(self):
