@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
           If a tensorboard plugin exist when you are reading this, go use that :)
@@ -168,7 +168,8 @@ if __name__ == "__main__":
 
         def plot_to_image(figure):
             """Converts the matplotlib plot specified by 'figure' to a PNG image and
-            returns it. The supplied figure is closed and inaccessible after this call."""
+            returns it. The supplied figure is closed and inaccessible after this call.
+            """
             # Save the plot to a PNG in memory.
             buf = io.BytesIO()
             pyplot.savefig(buf, format="png")
