@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
             TODO: Finish this off, only a placeholder for now
@@ -9,12 +9,13 @@ __doc__ = r"""
            Created on 17-03-2021
            """
 
+from typing import Sequence, MutableMapping, Any
+
 from draugr.tensorboard_utilities.exporting.event_export import TensorboardEventExporter
-from typing import Sequence, MutableMapping
 
 
 class TensorboardEventExporterFile(TensorboardEventExporter):
-    def __init__(self, *args: Sequence, **kwargs: MutableMapping):
+    def __init__(self, *args: Sequence[Any], **kwargs: MutableMapping[str, Any]):
         super().__init__(*args, **kwargs)
         self.file = kwargs.get("file")
         if self.file is not None:
@@ -23,7 +24,6 @@ class TensorboardEventExporterFile(TensorboardEventExporter):
             raise ValueError("No file provided")
 
     def export(self):
-
         self.file.write("")
         super().export()
 
