@@ -1,11 +1,11 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 
 from .architecture import *
 from .distributional import *
+from .experimental import *
 from .mlp import *
 from .mlp_variants import *
-from .vae import *
-from .experimental import *
 from .recurrent import *
+from .vae import *
