@@ -4,11 +4,10 @@ from typing import Iterable, List, Sequence, MutableMapping
 
 import numpy
 import torch
-
 from draugr.torch_utilities.architectures.mlp import MLP
 from draugr.torch_utilities.tensors.to_tensor import to_tensor
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = "Fusion variant of MLPs"
 
 __all__ = ["PreConcatInputMLP", "LateConcatInputMLP"]
@@ -54,7 +53,6 @@ class LateConcatInputMLP(MLP):
         fusion_hidden_multiplier: int = 10,
         **kwargs: MutableMapping
     ):
-
         forward_shape, *res = input_shape
         self._residual_shape = res
 
