@@ -5,7 +5,7 @@ from typing import Any, Sequence
 import torch
 from torch.utils.data import Dataset
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 09/10/2019
@@ -15,7 +15,7 @@ __all__ = ["RandomDataset"]
 
 
 class RandomDataset(Dataset):
-    """description"""
+    """Random dataset on instantiation"""
 
     def __init__(self, nd_size: Sequence, length: int):
         self.len = length
