@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 01/03/2020
@@ -23,7 +23,7 @@ from warg import drop_unused_kws
 
 class SupervisedDataset(Dataset):
     """
-    Supervised Dataset is comprised of separate Splits"""
+    Supervised Dataset comprises separate Splits"""
 
     @drop_unused_kws
     def __init__(self):
