@@ -1,18 +1,20 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 02-12-2020
            """
 
+from typing import Callable
+
 import torch
+from draugr.torch_utilities.sessions.model_sessions import TorchEvalSession
+from draugr.torch_utilities.system.device import global_torch_device
 from torch.utils.data import DataLoader
 from tqdm import tqdm
 
-from draugr.torch_utilities.sessions.model_sessions import TorchEvalSession
-from draugr.torch_utilities.system.device import global_torch_device
 from warg import kws_sink
 
 __all__ = ["find_n_misclassified"]
@@ -22,7 +24,7 @@ def find_n_misclassified(
     model: torch.nn.Module,
     evaluation_loader: DataLoader,
     *,
-    mapper: callable = kws_sink,
+    mapper: Callable = kws_sink,
     n: int = 10,
     device: torch.device = global_torch_device(),
 ) -> None:
