@@ -1,7 +1,7 @@
 # !/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 26-06-2021
@@ -110,5 +110,4 @@ def iasjduh() -> None:
 
 
 if __name__ == "__main__":
-
     adasdassijd()
