@@ -4,13 +4,13 @@ from typing import Iterable, Iterator, Tuple, Union, MutableMapping
 
 import numpy
 import torch
-from torch.utils.data.dataloader import DataLoader
-
 from draugr.torch_utilities.datasets import NonSequentialDataset
 from draugr.torch_utilities.tensors import to_tensor
+from torch.utils.data.dataloader import DataLoader
+
 from warg import passes_kws_to
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 28/10/2019
