@@ -3,7 +3,7 @@
 
 import torch
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 09/10/2019
