@@ -1,14 +1,14 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 23/07/2020
            """
 
+from .activations import *
 from .boxes_2d import *
 from .enums import *
 from .sizes import *
 from .torch_transforms import *
-from .activations import *
