@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 29/07/2020
@@ -11,28 +11,29 @@ __all__ = []
 
 import copy
 import math
+from typing import Callable
 
 import torch
-
 from draugr.torch_utilities.optimisation.parameters import (
     named_trainable_parameters,
     normal_init_weights,
     trainable_parameters,
 )
 from draugr.torch_utilities.sessions import TorchEvalSession
+
 from warg import ContextWrapper
 
 
 def loss_grad_check(
     model: torch.nn.Module,
-    loss_fn: callable,
+    loss_fn: Callable,
     iinput: torch.Tensor,
     target: torch.Tensor,
     epsilon: float = 1e-6,
     error_tolerance: float = 1e-5,
 ) -> None:
     """
-    two sided gradient numerical approximation
+    Two sided gradient numerical approximation
     DOES not work, please refer to torch/autograd/gradcheck.py
 
     :param iinput:
