@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
           Checklist items for ensuring optimisation is performed as expected.
@@ -27,7 +27,6 @@ use backprop to chart dependencies. Your deep learning code will often contain c
 from random import random
 
 import torch
-
 from draugr.torch_utilities.tensors import to_tensor
 
 __all__ = ["overfit_single_batch"]
