@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 27/06/2020
@@ -9,11 +9,10 @@ __doc__ = r"""
 
 __all__ = ["get_num_parameters"]
 
-from torch import nn
-
 from draugr.torch_utilities.optimisation.parameters.trainable import (
     trainable_parameters,
 )
+from torch import nn
 
 
 def get_num_parameters(model: nn.Module, *, only_trainable: bool = False) -> int:
