@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 02-12-2020
@@ -10,11 +10,10 @@ __doc__ = r"""
 from contextlib import contextmanager
 from itertools import tee
 
-from torch.nn import Module
-
 from draugr.torch_utilities.optimisation.parameters.freezing.parameters import (
     freeze_parameters,
 )
+from torch.nn import Module
 
 __all__ = ["freeze_model", "frozen_model"]
 
