@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 20/10/2019
@@ -12,7 +12,6 @@ __all__ = ["set_lr", "exponential_lr_decay", "average_learning_rate"]
 from statistics import mean
 
 import torch
-
 from torch.optim.optimizer import Optimizer
 
 
