@@ -5,17 +5,17 @@ import sys
 from typing import Optional
 
 import torch
-from torch.nn.modules.module import Module
-
 from draugr.torch_utilities.persistence.config import (
     ensure_directory_exist,
     save_config,
 )
+from torch.nn.modules.module import Module
+
 from warg import latest_file
 from warg import passes_kws_to
 from warg.decorators.kw_passing import drop_unused_kws
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 
 model_extension = ".model"
 config_extension = ".py"
