@@ -1,16 +1,16 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 11/05/2020
            """
 
 import torch
+from draugr.torch_utilities import global_torch_device
 from torch.nn import Module
 
-from draugr.torch_utilities import global_torch_device
 from warg import AlsoDecorator
 
 __all__ = ["TorchCpuSession", "TorchCudaSession", "TorchDeviceSession"]
