@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 11/05/2020
@@ -11,8 +11,8 @@ from collections import OrderedDict
 from itertools import tee
 
 import torch
-
 from draugr.torch_utilities.optimisation.parameters.freezing import freeze_parameters
+
 from warg import AlsoDecorator
 
 __all__ = [
