@@ -4,10 +4,9 @@ from typing import Union
 
 import numpy
 import torch
-
 from draugr.torch_utilities.tensors import to_tensor
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 09/10/2019
