@@ -5,7 +5,7 @@ from typing import Union
 
 import torch
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 15/11/2019
