@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 08-12-2020
@@ -14,7 +14,6 @@ from typing import Union
 
 import numpy
 import torch
-
 from draugr.torch_utilities.system.device import global_torch_device
 
 
