@@ -6,7 +6,7 @@ from typing import Any, Callable
 import numpy
 import torch
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 09/10/2019
