@@ -1,11 +1,11 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from typing import Iterable, Sequence, Union
+from typing import Iterable, Sequence, Union, Callable
 
 import numpy
 import torch
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = ""
 __all__ = ["to_scalar"]
 
@@ -16,7 +16,7 @@ from warg import Number
 def to_scalar(
     obj: Union[torch.Tensor, numpy.ndarray, Iterable, Sequence, int, float],
     device: Union[str, torch.device] = "cpu",
-    aggregation: callable = torch.mean,
+    aggregation: Callable = torch.mean,
 ) -> Number:
     """
     Always detaches from computation graph
