@@ -7,13 +7,16 @@ import torch
 import torchvision
 from PIL.Image import Image
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = ""
 __all__ = ["to_tensor"]
 
 from draugr.torch_utilities.tensors.types import numpy_to_torch_dtype
 
 
+# from warg import passes_kws_to
+
+
 # @passes_kws_to(torch.Tensor.to)
 def to_tensor(
     obj: Union[torch.Tensor, numpy.ndarray, Iterable, Sequence, int, float],
