@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 
 __doc__ = r"""
 
@@ -18,5 +18,4 @@ from .tensorboard import *
 from .torch_module_writer import *
 from .mixins import *
 
-
 # from .visdom import *
