@@ -2,9 +2,10 @@
 # -*- coding: utf-8 -*-
 from abc import ABC, abstractmethod
 from typing import Union, Sequence
+
 import torch
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 09/10/2019
