@@ -1,15 +1,14 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = ""
 __all__ = ["launch_tensorboard"]
 
 from pathlib import Path
 
-from tensorboard import program  # IMPORT OUT HERE; POSSIBLE RAISE CONDITIONS
-
 from draugr.python_utilities.sockets import is_port_in_use
+from tensorboard import program  # IMPORT OUT HERE; POSSIBLE RAISE CONDITIONS
 
 
 def launch_tensorboard(log_dir: Path, port: int = 6006) -> str:
