@@ -42,12 +42,14 @@ from draugr.writers.mixins.spectrogram_writer_mixin import SpectrogramWriterMixi
 from draugr.writers.writer import Writer
 from matplotlib import pyplot
 from matplotlib.figure import Figure
-from warg import drop_unused_kws, passes_kws_to, sprint
+
+from draugr.python_utilities.styling import sprint
+from warg import drop_unused_kws, passes_kws_to
 
 with suppress(FutureWarning):
     from torch.utils.tensorboard import SummaryWriter
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = """
 Created on 27/04/2019
 
@@ -220,7 +222,7 @@ class TensorBoardPytorchWriter(
         self._log_dir = path
         self._summary_writer_kws = summary_writer_kws
 
-    # @passes_kws_to(SummaryWriter.add_hparams)
+    @passes_kws_to(SummaryWriter.add_hparams)
     def instance(self, instance: dict, metrics: dict, **kwargs) -> None:
         """
 
@@ -564,7 +566,6 @@ pyplot.title(tag)
                             **kwargs,
                         )
                 else:
-
                     raise NotImplementedError(
                         f"{multi_channel_method} is not implemented"
                     )
@@ -607,7 +608,6 @@ TorchTensorBoardWriter = TensorBoardPytorchWriter
 PTW = TensorBoardPytorchWriter
 
 if __name__ == "__main__":
-
     with TensorBoardPytorchWriter(PROJECT_APP_PATH.user_log / "test") as writer:
         writer.scalar("What", 4)
 
