@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 10/07/2020
@@ -14,6 +14,8 @@ from draugr import PROJECT_APP_PATH
 # from draugr.torch_utilities.writers.tensorboard import TensorBoardPytorchWriter # Self reference issue
 from draugr.writers import HistogramWriterMixin
 
+# from warg import passes_kws_to
+
 __all__ = ["weight_bias_histograms"]
 
 
