@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 
 __doc__ = r"""
 """
@@ -13,10 +13,11 @@ with open(Path(__file__).parent / "README.md", "r") as this_init_file:
 # del Path
 
 try:
-    from .matplotlib_utilities import *
-    from .pillow_utilities import *
-    from .seaborn_utilities import *
-    from .progress import *
+    # from .matplotlib_utilities import *
+    # from .pillow_utilities import *
+    # from .seaborn_utilities import *
+    # from .progress import *
+    ...
 except ImportError as ix:
     this_package_name = Path(__file__).parent.name
     this_package_reqs = (
