@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 17/07/2020
@@ -14,10 +14,6 @@ from typing import Any, Sequence, Union
 
 import numpy
 from cycler import Cycler
-from matplotlib import patches, pyplot, rcParams
-from matplotlib.legend_handler import HandlerErrorbar
-from sorcery import assigned_names
-
 from draugr.visualisation.matplotlib_utilities.quirks import auto_post_hatch
 from draugr.visualisation.matplotlib_utilities.styles.annotation import (
     rt_ann_transform,
@@ -28,6 +24,9 @@ from draugr.visualisation.matplotlib_utilities.styles.cyclers import (
     monochrome_line_cycler,
     simple_hatch_cycler,
 )
+from matplotlib import patches, pyplot, rcParams
+from matplotlib.legend_handler import HandlerErrorbar
+from sorcery import assigned_names
 
 __all__ = [
     "denormalise_minusoneone",
