@@ -1,9 +1,9 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 import math
-from typing import Iterable, Iterator, Sequence, Tuple
+from typing import Iterable, Iterator, Sequence, Tuple, Any
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = """
 Created on 27/04/2019
 
@@ -128,7 +128,7 @@ def horizontal_imshow(
 def biplot(
     scores: Sequence,
     coefficients: numpy.ndarray,
-    categories: Iterable = None,
+    categories: Iterable[Any] = None,
     labels: Sequence = None,
     label_multiplier: float = 1.06,
 ) -> pyplot.Figure:
