@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 17-02-2021
@@ -10,11 +10,10 @@ __doc__ = r"""
 from enum import Enum
 from typing import Sequence, Optional
 
+from draugr.visualisation.matplotlib_utilities.styles.cyclers import simple_hatch_cycler
 from matplotlib import cycler, pyplot, rcParams
 from matplotlib.axes import Axes
 
-from draugr.visualisation.matplotlib_utilities.styles.cyclers import simple_hatch_cycler
-
 __all__ = [
     "fix_edge_gridlines",
     "auto_post_print_dpi",
@@ -114,7 +113,6 @@ def scatter_auto_mark(
             if isinstance(marker, mmarkers.MarkerStyle):
                 marker_obj = marker
             else:
-
                 marker_obj = mmarkers.MarkerStyle(marker, fillstyle=fillstyle)
             path = marker_obj.get_path().transformed(marker_obj.get_transform())
             paths.append(path)
