@@ -4,11 +4,12 @@ import logging
 import sys
 from typing import Any, MutableMapping
 
-from warg import ensure_existence
 from draugr import PROJECT_APP_PATH
 from draugr.writers.writer import Writer
 
-__author__ = "Christian Heider Nielsen"
+from warg import ensure_existence
+
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = """
 Created on 27/04/2019
 
