@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 from abc import ABC, abstractmethod
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 09/10/2019
@@ -14,7 +14,8 @@ from typing import Any, Sequence
 
 class EmbedWriterMixin(ABC):
     """
-    Writer mixin that provides an interface for 'writing' embeds/projections(2d,3d) for interactive visualisation"""
+    Writer mixin that provides an interface for 'writing' embeds/projections(2d,3d) for interactive visualisation
+    """
 
     @abstractmethod
     def embed(
