@@ -2,12 +2,13 @@
 # -*- coding: utf-8 -*-
 
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 09/10/2019
            """
 __all__ = ["LineWriterMixin"]
+
 from abc import ABC, abstractmethod
 from typing import Mapping, Sequence, MutableMapping
 
