@@ -7,7 +7,7 @@ import numpy
 import torch
 from PIL import Image
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 09/10/2019
