@@ -3,7 +3,7 @@
 from abc import ABC, abstractmethod
 from typing import Mapping, Sequence
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = r"""
 
            Created on 09/10/2019
