@@ -3,7 +3,7 @@
 
 from draugr.writers.writer import Writer
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = """
 Created on 27/04/2019
 
@@ -26,7 +26,6 @@ class ConsoleWriter(Writer):
 
 
 if __name__ == "__main__":
-
     with ConsoleWriter() as w:
         for i in range(10):
             w.scalar("lol", i)
