@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "Christian Heider Nielsen"
+__author__ = "Christian Heider Lindbjerg"
 __doc__ = """
 Created on 27/04/2019
 
@@ -11,7 +11,6 @@ Created on 27/04/2019
 from abc import ABCMeta, abstractmethod
 from collections import deque
 
-from draugr.python_utilities.counter_filter import CounterFilter
 from draugr.writers.mixins.scalar_writer_mixin import ScalarWriterMixin
 
 __all__ = ["Writer", "global_writer", "set_global_writer"]
@@ -56,7 +55,7 @@ class Writer(ScalarWriterMixin, metaclass=ABCMeta):
     def _open(self):
         return self
 
-    def __call__(self, *args: Sequence, **kwargs: MutableMapping):
+    def __call__(self, *args: Sequence[Any], **kwargs: MutableMapping[str, Any]):
         self.scalar(*args, *kwargs)
 
 
